/*

HC-MailBox.h Profile Definition File

This ZigBee Profile header file provides all of the constants needed to
implement a device that is conforms to the HC-MailBox profile.

End device binding must be implemented.
The HC-Mailbox profile uses the home controls profile

 
*/

#ifndef _ZHCMAILBOX_H_
#define _ZHCMAILBOX_H_

#define MY_PROFILE_ID                       0xC1EE      // Mailbox profile
#define MY_PROFILE_ID_MSB                   0x02
#define MY_PROFILE_ID_LSB                   0x00

#define MAILBOX_DEV_ID      				0xF000      // Mailbox node 
#define MAILBOX_DEV_ID_MSB  				0xF0
#define MAILBOX_DEV_ID_LSB 					0x00
#define MAILBOX_DEV_ID_VER  				0x00

#define MAILBOX_ALL_DEVICES_CLUSTER			0x00

#define MY_STACK_PROFILE_ID                 0x01		// Home Controls stack profile
#define PROFILE_nwkSecurityLevel            0x00        // TODO: should be 5 when security supported

#define PROFILE_nwkMaxChildren              20
#define PROFILE_nwkMaxDepth                 5
#define PROFILE_nwkMaxRouters               6

#define PROFILE_MinBindings                     100
#define PROFILE_MinCoordinatorNeighbors         24
#define PROFILE_MinRouterNeighbors              25
#define PROFILE_MinEndDeviceNeighbors           1
#define PROFILE_MinRouteDiscoveryTableSize      4
#define PROFILE_MinRoutingTableSize             8
#define PROFILE_MinReservedRoutingTableEntries  8

#define GROUP_TABLE_MAX						63			// current limitation is 63 nodes in group

//******************************************************************************
// Distributed Address Assignment Constants
//
// These should be calculated manually and placed here.  They are calculated by
// the following formulae.  CSKIP values should be generated until the max
// depth is reached or until CSKIP equals 0.
//
//  Cskip(d) =  if PROFILE_nwkMaxRouters is 1 =
//                  1 + Cm * (Lm - d - 1)
//              otherwise =
//                  1 + Cm - Rm - (Cm * Rm^(Lm - d - 1))
//                  ------------------------------------
//                                1 - Rm
//  where
//      Cm = PROFILE_nwkMaxChildren
//      Lm = PROFILE_nwkMaxDepth
//      Rm = PROFILE_nwkMaxRouters
//      d  = depth of node in the network

#define CSKIP_DEPTH_0                       0x143D
#define CSKIP_DEPTH_1                       0x035D
#define CSKIP_DEPTH_2                       0x008D
#define CSKIP_DEPTH_3                       0x0015
#define CSKIP_DEPTH_4                       0x0001
#define CSKIP_DEPTH_5                       0x0000


//******************************************************************************
// Mandatory Clusters

#define MailBox_Cluster        	0x10    // Mailbox message, uses MSG data type, not KVP
#define Reflash_Cluster			0x20

// constants
#define DiscoveryTimeout		(MIB_MailBoxTimeout*2)
#define ServDiscoTimeout		(MIB_MailBoxTimeout)
#define DataTimeout				(MIB_MailBoxTimeout)

//******************************************************************************
// Check User Assignments

// Check size of routing table
#if defined(I_SUPPORT_ROUTING)
    #if ROUTING_TABLE_SIZE < PROFILE_MinRoutingTableSize
        #error Routing Table size too small.  Check Profile description.
    #endif
    #if RESERVED_ROUTING_TABLE_ENTRIES < PROFILE_MinReservedRoutingTableEntries
        #error Reserved Routing Table entries too small.  Check Profile description.
    #endif
#endif

// Check size of neighbor table
#if defined(I_AM_COORDINATOR)
    #if MAX_NEIGHBORS < PROFILE_MinCoordinatorNeighbors
        #error Neighbor Table size too small.  Check Profile description.
    #endif
#elif defined (I_AM_ROUTER)
    #if MAX_NEIGHBORS < PROFILE_MinRouterNeighbors
        #error Neighbor Table size too small.  Check Profile description.
    #endif
#else
    #if MAX_NEIGHBORS < PROFILE_MinEndDeviceNeighbors
        #error Neighbor Table size too small.  Check Profile description.
    #endif
#endif

// Check size of route discovery table
#if defined(I_AM_ROUTER) || defined(I_AM_COORDINATOR)
    #if ROUTE_DISCOVERY_TABLE_SIZE < PROFILE_MinRouteDiscoveryTableSize
        #error Route Discovery Table size too small.  Check Profile description.
    #endif
#endif

// Check size of binding table
#if defined(I_AM_COORDINATOR)
    #if MAX_BINDINGS < PROFILE_MinBindings
        #error Binding Table size too small.  Check Profile description.
    #endif
#endif

// If coordinator, make sure that end device binding is supported.
#if defined(I_AM_COORDINATOR)
    #ifndef SUPPORT_END_DEVICE_BINDING
        #error This Profile requires that ZigBee coordinators support End Device Binding.
    #endif
#endif


#endif
